@@ -33,7 +33,7 @@ package Apache2::AMFLiteDetectionFilter;
   # 
 
   use vars qw($VERSION);
-  $VERSION= "4.11";;;
+  $VERSION= "4.12";;;
   my $CommonLib = new Apache2::AMFCommonLib ();
   my %MobileArray;#=$CommonLib->getMobileArray;
   my %MobileTabletArray;
@@ -450,7 +450,7 @@ sub getOperativeSystemVersion {
         $regex_param="android ([0-9]\\.[0-9](\\.[0-9])?)";
         $matchOS=1;
     } elsif ($os eq 'ios') {
-        $regex_param=" os ([0-9]\\_[0-9](\\_[0-9])?)";
+        $regex_param="os ((\\d+_?){2,3})\\s";
         $matchOS=1;
     } elsif ($os eq 'windows phone') {
         $regex_param="( phone| phone os) ([0-9]\\.[0-9](\\.[0-9])?)";
@@ -460,7 +460,7 @@ sub getOperativeSystemVersion {
         $matchOS=1;
     } 
     if ($matchOS == 1) {
-        ($return_value) = ($UserAgent =~ /$regex_param/);
+        ($return_value) = ($UserAgent =~ /$regex_param/i);
     }
     
   return $return_value;
